@@ -12,11 +12,11 @@
 
 #include <Rcpp.h>
 #include "ANN/ANN.h"
+#include "R_kNN.h"
 
 using namespace Rcpp;
 
 // returns knn + dist
-// [[Rcpp::export]]
 List kNN_int(NumericMatrix data, int k,
   int type, int bucketSize, int splitRule, double approx) {
 
